summaryrefslogtreecommitdiff
path: root/compiler/GHC/CmmToAsm.hs
diff options
context:
space:
mode:
authorTakenobu Tani <takenobu.hs@gmail.com>2020-05-30 23:11:59 +0900
committerMarge Bot <ben+marge-bot@smart-cactus.org>2020-06-10 03:39:59 -0400
commit2487912938f188cb264e4a11d21bf750adccc5e7 (patch)
tree13843cfd8f27bf6f1672a4e37d6af0e04bb34d18 /compiler/GHC/CmmToAsm.hs
parenta47e6442bc4be4a33339499d876792ba109e8d32 (diff)
downloadhaskell-2487912938f188cb264e4a11d21bf750adccc5e7.tar.gz
Clarify leaf module names for new module hierarchy
This updates comments only. This patch replaces leaf module names according to new module hierarchy [1][2] as followings: * Expand leaf names to easily find the module path: for instance, `Id.hs` to `GHC.Types.Id`. * Modify leaf names according to new module hierarchy: for instance, `Convert.hs` to `GHC.ThToHs`. * Fix typo: for instance, `GHC.Core.TyCo.Rep.hs` to `GHC.Core.TyCo.Rep` See also !3375 [1]: https://gitlab.haskell.org/ghc/ghc/-/wikis/Make-GHC-codebase-more-modular [2]: https://gitlab.haskell.org/ghc/ghc/issues/13009
Diffstat (limited to 'compiler/GHC/CmmToAsm.hs')
-rw-r--r--compiler/GHC/CmmToAsm.hs6
1 files changed, 3 insertions, 3 deletions
diff --git a/compiler/GHC/CmmToAsm.hs b/compiler/GHC/CmmToAsm.hs
index fa053e4e66..9252556b6a 100644
--- a/compiler/GHC/CmmToAsm.hs
+++ b/compiler/GHC/CmmToAsm.hs
@@ -289,7 +289,7 @@ data NativeGenAcc statics instr
, ngs_dwarfFiles :: !DwarfFiles
, ngs_unwinds :: !(LabelMap [UnwindPoint])
-- ^ see Note [Unwinding information in the NCG]
- -- and Note [What is this unwinding business?] in Debug.
+ -- and Note [What is this unwinding business?] in "GHC.Cmm.DebugBlock".
}
{-
@@ -314,7 +314,7 @@ field of NativeGenAcc. This is a label map which contains an entry for each
procedure, containing a list of unwinding points (e.g. a label and an associated
unwinding table).
-See also Note [What is this unwinding business?] in Debug.
+See also Note [What is this unwinding business?] in "GHC.Cmm.DebugBlock".
-}
nativeCodeGen' :: (Outputable statics, Outputable instr,Outputable jumpDest,
@@ -432,7 +432,7 @@ cmmNativeGenStream dflags this_mod modLoc ncgImpl h us cmm_stream ngs
dbgMap us cmms ngs 0
-- Link native code information into debug blocks
- -- See Note [What is this unwinding business?] in Debug.
+ -- See Note [What is this unwinding business?] in "GHC.Cmm.DebugBlock".
let !ldbgs = cmmDebugLink (ngs_labels ngs') (ngs_unwinds ngs') ndbgs
unless (null ldbgs) $
dumpIfSet_dyn dflags Opt_D_dump_debug "Debug Infos" FormatText